==> field_manager_python_client-4.4.90rc11.tar.gz: field_manager_python_client-4.4.90rc11/field_manager_python_client/api/cross_sections/update_cross_section_projects_project_id_cross_sections_cross_section_id_put.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.cross_section import CrossSection
from ...models.cross_section_update import CrossSectionUpdate
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    project_id: str,
    cross_section_id: UUID,
    *,
    body: CrossSectionUpdate,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "put",
        "url": f"/projects/{project_id}/cross_sections/{cross_section_id}",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[CrossSection, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = CrossSection.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[CrossSection, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Response[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CrossSection, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        cross_section_id=cross_section_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Optional[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CrossSection, HTTPValidationError]
    """

    return sync_detailed(
        project_id=project_id,
        cross_section_id=cross_section_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Response[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CrossSection, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        cross_section_id=cross_section_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Optional[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CrossSection, HTTPValidationError]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            cross_section_id=cross_section_id,
            client=client,
            body=body,
        )
    ).parsed

==> field_manager_python_client-4.6.7.tar.gz: field_manager_python_client-4.6.7/field_manager_python_client/api/cross_sections/update_cross_section_projects_project_id_cross_sections_cross_section_id_put.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.cross_section import CrossSection
from ...models.cross_section_update import CrossSectionUpdate
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    project_id: str,
    cross_section_id: UUID,
    *,
    body: CrossSectionUpdate,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": f"/projects/{project_id}/cross_sections/{cross_section_id}",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[CrossSection, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = CrossSection.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[CrossSection, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Response[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CrossSection, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        cross_section_id=cross_section_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Optional[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CrossSection, HTTPValidationError]
    """

    return sync_detailed(
        project_id=project_id,
        cross_section_id=cross_section_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Response[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[CrossSection, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        cross_section_id=cross_section_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    cross_section_id: UUID,
    *,
    client: AuthenticatedClient,
    body: CrossSectionUpdate,
) -> Optional[Union[CrossSection, HTTPValidationError]]:
    """Update Cross Section

     Update a cross section.

    Args:
        project_id (str):
        cross_section_id (UUID):
        body (CrossSectionUpdate):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[CrossSection, HTTPValidationError]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            cross_section_id=cross_section_id,
            client=client,
            body=body,
        )
    ).parsed
